.. raw:: html

    <h1 align="center">Sponsors</h1>

`Colour <https://github.com/colour-science/colour>`__ is an independent
`BSD-3-Clause <https://opensource.org/licenses/BSD-3-Clause>`__ Open Source
affiliated project of `NumFOCUS <https://numfocus.org>`__, a 501(c)(3)
nonprofit in the United States.

We are grateful 💖 for the support of our
`sponsors <https://github.com/colour-science/colour/blob/develop/SPONSORS.rst>`__.
If you'd like to join them, please consider
`becoming a sponsor on OpenCollective <https://opencollective.com/colour-science>`__.

.. raw:: html

    <h2 align="center">Gold Sponsors</h2>

.. raw:: html

    <table>
        <tbody>
            <tr>
                <td align="center" valign="middle">
                    <a href="https://makeup.land/" target="_blank">
                        <img width="288px" src="https://images.opencollective.com/makeup-land/28c2133/logo/512.png">
                    </a>
                    <p><a href="https://makeup.land/" target="_blank">makeup.land</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/JRGoldstone" target="_blank">
                        <img width="288px" src="https://pbs.twimg.com/profile_images/1310212058672103425/3tPPvC6m.jpg">
                    </a>
                    <p><a href="https://twitter.com/JRGoldstone" target="_blank">Joseph Goldstone</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://colorhythm.com" target="_blank">
                        <img width="288px" src="https://images.opencollective.com/colorhythm/9b4667d/logo/256.png">
                    </a>
                    <p><a href="https://colorhythm.com" target="_blank">Colorhythm</a></p>
                </td>
            </tr>
        </tbody>
    </table>


.. raw:: html

    <h2 align="center">Silver Sponsors</h2>

.. raw:: html

    <table>
        <tbody>
            <tr>
                <td align="center" valign="middle">
                    <a href="http://antlerpost.com/" target="_blank">
                        <img width="176px" src="https://pbs.twimg.com/profile_images/1394284009329504257/CZxrhA6x.jpg">
                    </a>
                    <p><a href="http://antlerpost.com/" target="_blank">Nick Shaw</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="176px" src="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="176px" src="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="176px" src="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="176px" src="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
            </tr>
        </tbody>
    </table>

.. raw:: html

    <h2 align="center">Bronze Sponsors</h2>

.. raw:: html

    <table>
        <tbody>
            <tr>
                <td align="center" valign="middle">
                    <a href="https://github.com/scoopxyz" target="_blank">
                        <img width="126px" src="https://avatars0.githubusercontent.com/u/22137450">
                    </a>
                    <p><a href="https://github.com/scoopxyz" target="_blank">Sean Cooper</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://caveacademy.com" target="_blank">
                        <img width="126px" src="https://pbs.twimg.com/profile_images/1264204657548812290/y3kmV4NM.jpg">
                    </a>
                    <p><a href="https://caveacademy.com" target="_blank">CAVE Academy</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://www.zhannaalekseeva.nyc" target="_blank">
                        <img width="126px" src="https://images.opencollective.com/studio-zhanna-alekseeva-nyc/a60e20f/avatar/256.png">
                    </a>
                    <p><a href="https://www.zhannaalekseeva.nyc" target="_blank">Studio Zhanna Alekseeva.NYC</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://opencollective.com/guest-b971dc73" target="_blank">
                        <img width="126px" src="https://opencollective.com/static/images/default-guest-logo.svg">
                    </a>
                    <p><a href="https://opencollective.com/guest-b971dc73" target="_blank">James Howard</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/126x126/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="126px" src="https://dummyimage.com/126x126/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/126x126/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="126px" src="https://dummyimage.com/126x126/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/126x126/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="126px" src="https://dummyimage.com/126x126/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
            </tr>
        </tbody>
    </table>

.. raw:: html

    <h2 align="center">Recurring Donations</h2>

.. raw:: html

    <table>
        <tbody>
            <tr>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/Pablo_g_soriano" target="_blank">
                        <img width="98px" src="https://images.opencollective.com/cromorama-sp-z-oo/67460ce/avatar/256.png">
                    </a>
                    <p><a href="https://twitter.com/Pablo_g_soriano" target="_blank">Pablo Garcia Soriano</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
            </tr>
        </tbody>
    </table>

.. raw:: html

    <h2 align="center">Donations & Special Sponsors</h2>

.. raw:: html

    <table>
        <tbody>
            <tr>
                <td align="center" valign="middle">
                    <a href="https://www.jetbrains.com/" target="_blank">
                        <img height="176px" src="https://i.imgur.com/nN1VDUG.png">
                    </a>
                    <p><a href="https://www.jetbrains.com/" target="_blank">JetBrains</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://github.com/sobotka" target="_blank">
                        <img width="176px" src="https://avatars2.githubusercontent.com/u/59577">
                    </a>
                    <p><a href="https://github.com/sobotka" target="_blank">Troy James Sobotka</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://github.com/remia" target="_blank">
                        <img width="176px" src="https://avatars3.githubusercontent.com/u/1922806">
                    </a>
                    <p><a href="https://github.com/remia" target="_blank">Remi Achard</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="http://virtualmatter.org/" target="_blank">
                        <img width="176px" src="https://ca.slack-edge.com/T02KH93GH-UCFD09UUT-g2f156f5e08e-512">
                    </a>
                    <p><a href="http://virtualmatter.org/" target="_blank">Kevin Whitfield</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://www.richardlackey.com/" target="_blank">
                        <img width="176px" src="https://pbs.twimg.com/profile_images/1384145243096829962/CoUQPhrP.jpg">
                    </a>
                    <p><a href="https://www.richardlackey.com/" target="_blank">Richard Lackey</a></p>
                </td>
            </tr>
            <tr>
                <td align="center" valign="middle">
                    <a href="https://www.artstation.com/monsieur_lixm" target="_blank">
                        <img width="176px" src="https://pbs.twimg.com/profile_images/1469781977280786433/NncWAxCW.jpg">
                    </a>
                    <p><a href="https://www.artstation.com/monsieur_lixm" target="_blank">Liam Collod</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/alexmitchellmus" target="_blank">
                        <img width="176px" src="https://pbs.twimg.com/profile_images/763631280722370560/F9FN4lEz.jpg">
                    </a>
                    <p><a href="https://twitter.com/alexmitchellmus" target="_blank">Alex Mitchell</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/ilia_sibiryakov" target="_blank">
                        <img width="176px" src="https://avatars.githubusercontent.com/u/23642861">
                    </a>
                    <p><a href="https://twitter.com/ilia_sibiryakov" target="_blank">Ilia Sibiryakov</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://github.com/zachlewis" target="_blank">
                        <img width="176px" src="https://avatars0.githubusercontent.com/u/2228592">
                    </a>
                    <p><a href="https://github.com/zachlewis" target="_blank">Zack Lewis</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/fredsavoir" target="_blank">
                        <img width="176px" src="https://pbs.twimg.com/profile_images/363988638/FS_Portrait082009.jpg">
                    </a>
                    <p><a href="https://twitter.com/fredsavoir" target="_blank">Frederic Savoir</a></p>
                </td>
            </tr>
            <tr>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/hdc_digital" target="_blank">
                        <img width="176px" src="https://images.squarespace-cdn.com/content/v1/5ef3250008605a61d88e7240/1593263686377-LPNJQMBE7U00WRNBY6JH/DIT+Logo+-+Dark+theme+-+PNG.png">
                    </a>
                    <p><a href="https://www.digitalimagingtech.co.uk" target="_blank">Howard Colin</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://chrisbrejon.com/" target="_blank">
                        <img width="176px" src="https://i.imgur.com/Zhs53S9.png">
                    </a>
                    <p><a href="https://chrisbrejon.com/" target="_blank">Christophe Brejon</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/MarioRokicki" target="_blank">
                        <img width="176px" src="https://pbs.twimg.com/profile_images/1801891382/mario_pi_sq_400x400.jpg">
                    </a>
                    <p><a href="https://twitter.com/MarioRokicki" target="_blank">Mario Rokicki</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://opencollective.com/joshua-pines" target="_blank">
                        <img width="176px" src="https://images.opencollective.com/joshua-pines/ad0ec4b/avatar/256.png">
                    </a>
                    <p><a href="https://opencollective.com/joshua-pines" target="_blank">Joshua Pines</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="176px" src="https://dummyimage.com/176x176/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
            </tr>
        </tbody>
    </table>

.. raw:: html

    <h3 align="center">Coffee Sponsors</h3>

.. raw:: html

    <table>
        <tbody>
            <tr>
                <td align="center" valign="middle">
                    <a href="https://opencollective.com/static/images/default-anonymous-logo.svg" target="_blank">
                        <img width="98px" src="https://opencollective.com/static/images/default-anonymous-logo.svg">
                    </a>
                    <p><a href="" target="_blank">Anonymous</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://twitter.com/CLVPTY" target="_blank">
                        <img width="98px" src="https://pbs.twimg.com/profile_images/973315780388540416/KEddjwch_400x400.jpg">
                    </a>
                    <p><a href="https://twitter.com/CLVPTY" target="_blank">Cedric Lejeune</a></p>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
                <td align="center" valign="middle">
                    <a href="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here" target="_blank">
                        <img width="98px" src="https://dummyimage.com/98x98/f9f9fc/000000.png&text=Your+Logo+Here">
                    </a>
                </td>
            </tr>
        </tbody>
    </table>

.. raw:: html

    <h3 align="center">Sugar Sponsors</h3>

.. raw:: html

    <a href="https://opencollective.com/colour-science#sugar-sponsorship" target="_blank"><img src="https://opencollective.com/colour-science/tiers/sugar-sponsorship.svg?avatarHeight=36"></a>
